@@ -1,15 +1,16 @@
 package Test::HTTP::Server;
+$Test::HTTP::Server::VERSION = '0.04';
 #
 # 2011 (c) Przemysław Iskra <sparky@pld-linux.org>
 #		This program is free software,
 # you may distribute it under the same terms as Perl.
 #
+use 5.006;
 use strict;
 use warnings;
 use IO::Socket;
 use POSIX ":sys_wait_h";
 
-our $VERSION = '0.02';
 
 sub _open_socket
 {
@@ -41,7 +42,11 @@ sub new
 	die "Could not fork\n"
 		unless defined $pid;
 	if ( $pid ) {
-		my $self = { port => $port, pid => $pid };
+		my $self = {
+			address => "127.0.0.1",
+			port => $port,
+			pid => $pid,
+		};
 		return bless $self, $class;
 	} else {
 		$SIG{CHLD} = \&_sigchld;
@@ -54,7 +59,22 @@ sub new
 sub uri
 {
 	my $self = shift;
-	return "http://127.0.0.1:$self->{port}/";
+	return "http://$self->{address}:$self->{port}/";
+}
+
+sub port
+{
+	my $self = shift;
+	$self->{port};
+}
+
+sub address
+{
+	my $self = shift;
+	if ( @_ ) {
+		$self->{address} = shift;
+	}
+	$self->{address};
 }
 
 sub _sigchld
@@ -106,7 +126,7 @@ sub _main_loop
 }
 
 package Test::HTTP::Server::Connection;
-
+$Test::HTTP::Server::Connection::VERSION = '0.04';
 BEGIN {
 	eval {
 		require URI::Escape;
@@ -121,10 +141,8 @@ BEGIN {
 	}
 }
 
-use constant {
-	DNAME => [qw(Sun Mon Tue Wed Thu Fri Sat)],
-	MNAME => [qw(Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec)],
-};
+use constant DNAME => [qw(Sun Mon Tue Wed Thu Fri Sat)];
+use constant MNAME => [qw(Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec)];
 
 sub _http_time
 {
@@ -261,11 +279,13 @@ sub out_all
 	);
 	$self->{out_headers} = { %default_headers };
 
-	my $req = $self->{request}->[1];
-	$req =~ s#^/##;
+    my $raw_uri = $self->{request}->[1];
+    my @req_parts = split m#\?#, $raw_uri;
+    my $req = shift @req_parts;
+	$req =~ s#^/+##;
 	my @args = map { uri_unescape $_ } split m#/#, $req;
 	my $func = shift @args;
-	$func = "index" unless length $func;
+	$func = "index" unless defined $func and length $func;
 
 	my $body;
 	eval {
@@ -348,12 +368,15 @@ sub repeat
 }
 
 package Test::HTTP::Server::Request;
+$Test::HTTP::Server::Request::VERSION = '0.04';
 our @ISA = qw(Test::HTTP::Server::Connection);
 
 1;
 
 __END__
 
+=encoding UTF-8
+
 =head1 NAME
 
 Test::HTTP::Server - simple forking http server
@@ -405,4 +428,16 @@ Sends a pattern.
 
 =back
 
+=head1 AUTHOR
+
+Przemysław Iskra E<lt>sparky@cpan.orgE<gt>
+
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Przemysław Iskra.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
